@@ -10,22 +10,32 @@ logger = logging.getLogger(__name__)
 
 
 def frame_iterator(frame):
+    """
+    Yields frames till there are no more.
+    """
     while frame:
         yield frame
         frame = frame.f_back
 
 
 def format_stack(skip=0, length=6, _sep=os.path.sep):
+    """
+    Returns a one-line string with the current callstack.
+    """
     return ' < '.join("%s:%s:%s" % (
         '/'.join(f.f_code.co_filename.split(_sep)[-2:]),
         f.f_lineno,
         f.f_code.co_name
     ) for f in islice(frame_iterator(sys._getframe(1 + skip)), length))
 
-ASCII_ONLY = ''.join(i if i in string.printable else '.' for i in (chr(c) for c in range(256)))
+PRINTABLE = string.digits + string.ascii_letters + string.punctuation + ' '
+ASCII_ONLY = ''.join(i if i in PRINTABLE else '.' for i in (chr(c) for c in range(256)))
 
 
 def strip_non_ascii(val):
+    """
+    Convert to string (using `str`) and replace non-ascii characters with a dot (``.``).
+    """
     return str(val).translate(ASCII_ONLY)
 
 
@@ -42,6 +52,26 @@ def log(func=None,
         result_repr=strip_non_ascii,
         use_logging='CRITICAL',
         print_to=None):
+    """
+    Decorates `func` to have logging.
+
+    :param function func: Function to decorate. If missing log returns a partial which you can use as a decorator.
+    :param int stacktrace: Number of frames to show.
+    :param int stacktrace_align: Column to align the framelist to.
+    :param list attributes: List of instance attributes to show, in case the function is a instance method.
+    :param bool module: Show the module.
+    :param bool arguments: If ``True``, then show arguments.
+    :param bool arguments_repr: Function to convert one argument to a string.
+    :param bool result: If ``True``, then show result.
+    :param bool exception: If ``True``, then show exceptions.
+    :param function exception_repr: Function to convert an exception to a string.
+    :param function result_repr: Function to convert the result object to a string.
+    :param string use_logging: Emit log messages with the given loglevel.
+    :param fileobject print_to: File object to write to, in case you don't want to use logging module.
+
+    :returns: A decorator or a wrapper.
+    """
+
     loglevel = use_logging and logging._levelNames.get(use_logging, logging.CRITICAL)
 
     def dump(buf):
